# Projekt: 
TARGET = data_logger_avr

# MCU name
MCU = atmega128

CC = avr-gcc
LD = avr-ld
OBJCOPY = avr-objcopy

# Optimization level, can be [0, 1, 2, 3, s]. 0 turns off optimization.
OPT = 0

CFLAGS  = -g -O$(OPT) 
#LDFLAGS = -Map=$(TARGET).map,--cref

SOURCES  = main.c
SOURCES += system.c

OBJECTS = $(SOURCES:.c=.o)

# Includes for libs
INCDIRS  = -I ./../../components/clock/api 
INCDIRS += -I ./../../components/sys



# libs
LDFLAGS += -L./../../components
#LDFLAGS += -L .
LDFLAGS += -l clock

CFLAGS += $(INCDIRS)
CFLAGS += -mmcu=atmega128 


all:    start \
	$(TARGET).elf \
	extcoff \
	end



# Convert ELF to COFF for use in debugging / simulating in
# AVR Studio or VMLAB.
COFFCONVERT=$(OBJCOPY) --debugging \
	--change-section-address .data-0x800000 \
	--change-section-address .bss-0x800000 \
	--change-section-address .noinit-0x800000 \
	--change-section-address .eeprom-0x810000 



# Compile: create object files from C source files.
%.o : %.c
	@echo
	@echo $(MSG_COMPILE) $<
	$(CC) -c $(CFLAGS) $< -o $@ 
	@echo $(MSG_COMPILE_END) $<


# Link: create ELF output file from object files.
.SECONDARY : $(TARGET).elf
.PRECIOUS : $(OBJECTS)
%.elf: $(OBJECTS)
	@echo $(MSG_LINKING) $@
	$(CC) $(LDFLAGS) $(OBJECTS) -o $@ 
	@echo $(MSG_LINKING_END) $@


extcoff: $(TARGET).elf
	@echo
	@echo $(MSG_EXTENDED_COFF) $(TARGET).cof
	$(COFFCONVERT) -O coff-ext-avr $< $(TARGET).cof
	@echo $(MSG_EXTENDED_COFF_END)


DEPENDFILE = dependencies.dep

dep: $(SOURCES)
	$(CC) -MM $(SOURCES) > $(DEPENDFILE)

-include $(DEPENDFILE)



start:
	@echo
	@echo --------------- Projekt: $(TARGET) ---------------
	@echo

end:
	@echo
	@echo ----------------- End: $(TARGET) -----------------
	@echo


MSG_COMPILE     = --------------- Compile:
MSG_COMPILE_END = --------------- End Compile

MSG_LINKING     = --------------- Linking:
MSG_LINKING_END = --------------- End Linking

MSG_EXTENDED_COFF      = --------------- Coff Convert:
MSG_EXTENDED_COFF_END += --------------- End Coff Convert
